# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'event_date': 'datetime',
        'track_id': 'str',
        'event_type': 'str',
        'lock_status': 'str',
        'lock_host_name': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision': 'int',
        'replication_filter': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'event_date': 'EventDate',
        'track_id': 'TrackId',
        'event_type': 'EventType',
        'lock_status': 'LockStatus',
        'lock_host_name': 'LockHostName',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision': 'Revision',
        'replication_filter': 'ReplicationFilter'
    }

    def __init__(self, id=None, name=None, event_date=None, track_id=None, event_type=None, lock_status=None, lock_host_name=None, last_update_date_utc=None, last_update_user=None, revision=None, replication_filter=None, _configuration=None):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._event_date = None
        self._track_id = None
        self._event_type = None
        self._lock_status = None
        self._lock_host_name = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision = None
        self._replication_filter = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.event_date = event_date
        self.track_id = track_id
        if event_type is not None:
            self.event_type = event_type
        if lock_status is not None:
            self.lock_status = lock_status
        if lock_host_name is not None:
            self.lock_host_name = lock_host_name
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision is not None:
            self.revision = revision
        if replication_filter is not None:
            self.replication_filter = replication_filter

    @property
    def id(self):
        """Gets the id of this Event.  # noqa: E501

        The unique event Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Event.  # noqa: E501

        :return: The id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Event.

        The unique event Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Event.  # noqa: E501

        :param id: The id of this Event.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Event.  # noqa: E501

        The event name  # noqa: E501

        :return: The name of this Event.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Event.

        The event name  # noqa: E501

        :param name: The name of this Event.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def event_date(self):
        """Gets the event_date of this Event.  # noqa: E501

        The event date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The event_date of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._event_date

    @event_date.setter
    def event_date(self, event_date):
        """Sets the event_date of this Event.

        The event date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param event_date: The event_date of this Event.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and event_date is None:
            raise ValueError("Invalid value for `event_date`, must not be `None`")  # noqa: E501

        self._event_date = event_date

    @property
    def track_id(self):
        """Gets the track_id of this Event.  # noqa: E501

        The track unique id where the event takes place.  # noqa: E501

        :return: The track_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._track_id

    @track_id.setter
    def track_id(self, track_id):
        """Sets the track_id of this Event.

        The track unique id where the event takes place.  # noqa: E501

        :param track_id: The track_id of this Event.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and track_id is None:
            raise ValueError("Invalid value for `track_id`, must not be `None`")  # noqa: E501

        self._track_id = track_id

    @property
    def event_type(self):
        """Gets the event_type of this Event.  # noqa: E501

        The type of the event.  # noqa: E501

        :return: The event_type of this Event.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this Event.

        The type of the event.  # noqa: E501

        :param event_type: The event_type of this Event.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def lock_status(self):
        """Gets the lock_status of this Event.  # noqa: E501

        The lock status of the event.  # noqa: E501

        :return: The lock_status of this Event.  # noqa: E501
        :rtype: str
        """
        return self._lock_status

    @lock_status.setter
    def lock_status(self, lock_status):
        """Sets the lock_status of this Event.

        The lock status of the event.  # noqa: E501

        :param lock_status: The lock_status of this Event.  # noqa: E501
        :type: str
        """
        allowed_values = ["Free", "LockedByAnotherServer", "LockedByMyServer"]  # noqa: E501
        if (self._configuration.client_side_validation and
                lock_status not in allowed_values):
            raise ValueError(
                "Invalid value for `lock_status` ({0}), must be one of {1}"  # noqa: E501
                .format(lock_status, allowed_values)
            )

        self._lock_status = lock_status

    @property
    def lock_host_name(self):
        """Gets the lock_host_name of this Event.  # noqa: E501

        The name of the serveur which has locked the event.  # noqa: E501

        :return: The lock_host_name of this Event.  # noqa: E501
        :rtype: str
        """
        return self._lock_host_name

    @lock_host_name.setter
    def lock_host_name(self, lock_host_name):
        """Sets the lock_host_name of this Event.

        The name of the serveur which has locked the event.  # noqa: E501

        :param lock_host_name: The lock_host_name of this Event.  # noqa: E501
        :type: str
        """

        self._lock_host_name = lock_host_name

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Event.  # noqa: E501

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Event.

        The last utc date time when the properties of this object have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Event.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Event.  # noqa: E501

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Event.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Event.

        The name of the last user having updated this object.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Event.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision(self):
        """Gets the revision of this Event.  # noqa: E501

        The revision number of the object.  # noqa: E501

        :return: The revision of this Event.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Event.

        The revision number of the object.  # noqa: E501

        :param revision: The revision of this Event.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def replication_filter(self):
        """Gets the replication_filter of this Event.  # noqa: E501

        The level of the filter used for the replication  # noqa: E501

        :return: The replication_filter of this Event.  # noqa: E501
        :rtype: str
        """
        return self._replication_filter

    @replication_filter.setter
    def replication_filter(self, replication_filter):
        """Sets the replication_filter of this Event.

        The level of the filter used for the replication  # noqa: E501

        :param replication_filter: The replication_filter of this Event.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotForReplication", "ForReplication"]  # noqa: E501
        if (self._configuration.client_side_validation and
                replication_filter not in allowed_values):
            raise ValueError(
                "Invalid value for `replication_filter` ({0}), must be one of {1}"  # noqa: E501
                .format(replication_filter, allowed_values)
            )

        self._replication_filter = replication_filter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Event, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Event):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class TireSetApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def tire_set_create_tire_set(self, new_tire_set, **kwargs):  # noqa: E501
        """Create a new tireset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_create_tire_set(new_tire_set, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TireSet new_tire_set: The tireset to create. (required)
        :return: TireSet
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tire_set_create_tire_set_with_http_info(new_tire_set, **kwargs)  # noqa: E501
        else:
            (data) = self.tire_set_create_tire_set_with_http_info(new_tire_set, **kwargs)  # noqa: E501
            return data

    def tire_set_create_tire_set_with_http_info(self, new_tire_set, **kwargs):  # noqa: E501
        """Create a new tireset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_create_tire_set_with_http_info(new_tire_set, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TireSet new_tire_set: The tireset to create. (required)
        :return: TireSet
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_tire_set']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tire_set_create_tire_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_tire_set' is set
        if self.api_client.client_side_validation and ('new_tire_set' not in params or
                                                       params['new_tire_set'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_tire_set` when calling `tire_set_create_tire_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_tire_set' in params:
            body_params = params['new_tire_set']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tireset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TireSet',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tire_set_delete_tire_set(self, tire_set_id, **kwargs):  # noqa: E501
        """Delete an existing tireset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_delete_tire_set(tire_set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tire_set_id: The unique tireset id for which you want to delete the tireset (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tire_set_delete_tire_set_with_http_info(tire_set_id, **kwargs)  # noqa: E501
        else:
            (data) = self.tire_set_delete_tire_set_with_http_info(tire_set_id, **kwargs)  # noqa: E501
            return data

    def tire_set_delete_tire_set_with_http_info(self, tire_set_id, **kwargs):  # noqa: E501
        """Delete an existing tireset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_delete_tire_set_with_http_info(tire_set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tire_set_id: The unique tireset id for which you want to delete the tireset (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tire_set_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tire_set_delete_tire_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tire_set_id' is set
        if self.api_client.client_side_validation and ('tire_set_id' not in params or
                                                       params['tire_set_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tire_set_id` when calling `tire_set_delete_tire_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tire_set_id' in params:
            path_params['tireSetId'] = params['tire_set_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tireset/{tireSetId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tire_set_get_tire_set(self, tire_set_id, **kwargs):  # noqa: E501
        """Get a tireset via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_get_tire_set(tire_set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tire_set_id: The unique tireset id for which you want to get the tireset (required)
        :return: TireSet
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tire_set_get_tire_set_with_http_info(tire_set_id, **kwargs)  # noqa: E501
        else:
            (data) = self.tire_set_get_tire_set_with_http_info(tire_set_id, **kwargs)  # noqa: E501
            return data

    def tire_set_get_tire_set_with_http_info(self, tire_set_id, **kwargs):  # noqa: E501
        """Get a tireset via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_get_tire_set_with_http_info(tire_set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tire_set_id: The unique tireset id for which you want to get the tireset (required)
        :return: TireSet
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tire_set_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tire_set_get_tire_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tire_set_id' is set
        if self.api_client.client_side_validation and ('tire_set_id' not in params or
                                                       params['tire_set_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tire_set_id` when calling `tire_set_get_tire_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tire_set_id' in params:
            path_params['tireSetId'] = params['tire_set_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tireset/{tireSetId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TireSet',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tire_set_get_tire_sets_list(self, event_id, **kwargs):  # noqa: E501
        """Get the list of all tiresets for an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_get_tire_sets_list(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to get the tireset list (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tire_set_get_tire_sets_list_with_http_info(event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.tire_set_get_tire_sets_list_with_http_info(event_id, **kwargs)  # noqa: E501
            return data

    def tire_set_get_tire_sets_list_with_http_info(self, event_id, **kwargs):  # noqa: E501
        """Get the list of all tiresets for an event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_get_tire_sets_list_with_http_info(event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The unique event id for which you want to get the tireset list (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tire_set_get_tire_sets_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `tire_set_get_tire_sets_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/tiresets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tire_set_update_tire_set(self, tire_set_id, updated_tire_set, **kwargs):  # noqa: E501
        """Update an existing TireSet  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_update_tire_set(tire_set_id, updated_tire_set, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tire_set_id: The unique tireset id for which you want to update the tireset (required)
        :param TireSet updated_tire_set: The tireset to update. (required)
        :return: TireSet
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tire_set_update_tire_set_with_http_info(tire_set_id, updated_tire_set, **kwargs)  # noqa: E501
        else:
            (data) = self.tire_set_update_tire_set_with_http_info(tire_set_id, updated_tire_set, **kwargs)  # noqa: E501
            return data

    def tire_set_update_tire_set_with_http_info(self, tire_set_id, updated_tire_set, **kwargs):  # noqa: E501
        """Update an existing TireSet  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tire_set_update_tire_set_with_http_info(tire_set_id, updated_tire_set, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tire_set_id: The unique tireset id for which you want to update the tireset (required)
        :param TireSet updated_tire_set: The tireset to update. (required)
        :return: TireSet
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tire_set_id', 'updated_tire_set']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tire_set_update_tire_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tire_set_id' is set
        if self.api_client.client_side_validation and ('tire_set_id' not in params or
                                                       params['tire_set_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tire_set_id` when calling `tire_set_update_tire_set`")  # noqa: E501
        # verify the required parameter 'updated_tire_set' is set
        if self.api_client.client_side_validation and ('updated_tire_set' not in params or
                                                       params['updated_tire_set'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_tire_set` when calling `tire_set_update_tire_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tire_set_id' in params:
            path_params['tireSetId'] = params['tire_set_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_tire_set' in params:
            body_params = params['updated_tire_set']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/tireset/{tireSetId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TireSet',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Revision(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'date_revision': 'datetime',
        'maturity': 'int',
        'value': 'list[object]',
        'parameter_id': 'str',
        'is_obsolete': 'bool',
        'parameter_value_check_sum': 'str',
        'comment': 'str',
        'user_name': 'str',
        'last_update_date_utc': 'datetime',
        'is_new': 'bool',
        'data_updated_date': 'datetime',
        'data_axe_x': 'list[float]',
        'data_axe_y': 'list[float]',
        'data_axe_z': 'list[float]'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'date_revision': 'DateRevision',
        'maturity': 'Maturity',
        'value': 'Value',
        'parameter_id': 'ParameterId',
        'is_obsolete': 'IsObsolete',
        'parameter_value_check_sum': 'ParameterValueCheckSum',
        'comment': 'Comment',
        'user_name': 'UserName',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'is_new': 'IsNew',
        'data_updated_date': 'DataUpdatedDate',
        'data_axe_x': 'DataAxeX',
        'data_axe_y': 'DataAxeY',
        'data_axe_z': 'DataAxeZ'
    }

    def __init__(self, id=None, name=None, date_revision=None, maturity=None, value=None, parameter_id=None, is_obsolete=None, parameter_value_check_sum=None, comment=None, user_name=None, last_update_date_utc=None, is_new=None, data_updated_date=None, data_axe_x=None, data_axe_y=None, data_axe_z=None, _configuration=None):  # noqa: E501
        """Revision - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._date_revision = None
        self._maturity = None
        self._value = None
        self._parameter_id = None
        self._is_obsolete = None
        self._parameter_value_check_sum = None
        self._comment = None
        self._user_name = None
        self._last_update_date_utc = None
        self._is_new = None
        self._data_updated_date = None
        self._data_axe_x = None
        self._data_axe_y = None
        self._data_axe_z = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.date_revision = date_revision
        if maturity is not None:
            self.maturity = maturity
        self.value = value
        self.parameter_id = parameter_id
        if is_obsolete is not None:
            self.is_obsolete = is_obsolete
        if parameter_value_check_sum is not None:
            self.parameter_value_check_sum = parameter_value_check_sum
        if comment is not None:
            self.comment = comment
        if user_name is not None:
            self.user_name = user_name
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if is_new is not None:
            self.is_new = is_new
        if data_updated_date is not None:
            self.data_updated_date = data_updated_date
        if data_axe_x is not None:
            self.data_axe_x = data_axe_x
        if data_axe_y is not None:
            self.data_axe_y = data_axe_y
        if data_axe_z is not None:
            self.data_axe_z = data_axe_z

    @property
    def id(self):
        """Gets the id of this Revision.  # noqa: E501

        The unique revision id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new revision.  # noqa: E501

        :return: The id of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Revision.

        The unique revision id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new revision.  # noqa: E501

        :param id: The id of this Revision.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Revision.  # noqa: E501

        The revision name.  Must be unique for a parameter.  # noqa: E501

        :return: The name of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Revision.

        The revision name.  Must be unique for a parameter.  # noqa: E501

        :param name: The name of this Revision.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def date_revision(self):
        """Gets the date_revision of this Revision.  # noqa: E501

        The creation date of the revision.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The date_revision of this Revision.  # noqa: E501
        :rtype: datetime
        """
        return self._date_revision

    @date_revision.setter
    def date_revision(self, date_revision):
        """Sets the date_revision of this Revision.

        The creation date of the revision.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param date_revision: The date_revision of this Revision.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_revision is None:
            raise ValueError("Invalid value for `date_revision`, must not be `None`")  # noqa: E501

        self._date_revision = date_revision

    @property
    def maturity(self):
        """Gets the maturity of this Revision.  # noqa: E501

        The revision maturity. Should be an integer value between [0 and 100]  # noqa: E501

        :return: The maturity of this Revision.  # noqa: E501
        :rtype: int
        """
        return self._maturity

    @maturity.setter
    def maturity(self, maturity):
        """Sets the maturity of this Revision.

        The revision maturity. Should be an integer value between [0 and 100]  # noqa: E501

        :param maturity: The maturity of this Revision.  # noqa: E501
        :type: int
        """

        self._maturity = maturity

    @property
    def value(self):
        """Gets the value of this Revision.  # noqa: E501

        The revision value.  Depending on the parameter definition the value can be a single value or 2D value or 3D.  For this reason, the Value is represented as a 3 dimensionals JSON array.  The value type can be a string or double depending on the parameter.  For this reason, you have to serialize the value with invariant culture format.  Decimal separator must be the point. The coma is use to separate the elements inside the array.  Single Value sample : [[[0.7]]]  1D Value sample : [[[0.0]],[[0.1]],[[0.2]]]  2D Value sample : [[[1.0],[1.0],[1.0]], [[1.0],[1.0],[1.0],[1.0]]]  # noqa: E501

        :return: The value of this Revision.  # noqa: E501
        :rtype: list[object]
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Revision.

        The revision value.  Depending on the parameter definition the value can be a single value or 2D value or 3D.  For this reason, the Value is represented as a 3 dimensionals JSON array.  The value type can be a string or double depending on the parameter.  For this reason, you have to serialize the value with invariant culture format.  Decimal separator must be the point. The coma is use to separate the elements inside the array.  Single Value sample : [[[0.7]]]  1D Value sample : [[[0.0]],[[0.1]],[[0.2]]]  2D Value sample : [[[1.0],[1.0],[1.0]], [[1.0],[1.0],[1.0],[1.0]]]  # noqa: E501

        :param value: The value of this Revision.  # noqa: E501
        :type: list[object]
        """
        if self._configuration.client_side_validation and value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def parameter_id(self):
        """Gets the parameter_id of this Revision.  # noqa: E501

        The parameter unique Id to which the revision belongs to  # noqa: E501

        :return: The parameter_id of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._parameter_id

    @parameter_id.setter
    def parameter_id(self, parameter_id):
        """Sets the parameter_id of this Revision.

        The parameter unique Id to which the revision belongs to  # noqa: E501

        :param parameter_id: The parameter_id of this Revision.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and parameter_id is None:
            raise ValueError("Invalid value for `parameter_id`, must not be `None`")  # noqa: E501

        self._parameter_id = parameter_id

    @property
    def is_obsolete(self):
        """Gets the is_obsolete of this Revision.  # noqa: E501

        Return true if the revision is obsolete  # noqa: E501

        :return: The is_obsolete of this Revision.  # noqa: E501
        :rtype: bool
        """
        return self._is_obsolete

    @is_obsolete.setter
    def is_obsolete(self, is_obsolete):
        """Sets the is_obsolete of this Revision.

        Return true if the revision is obsolete  # noqa: E501

        :param is_obsolete: The is_obsolete of this Revision.  # noqa: E501
        :type: bool
        """

        self._is_obsolete = is_obsolete

    @property
    def parameter_value_check_sum(self):
        """Gets the parameter_value_check_sum of this Revision.  # noqa: E501

        The checksum of the value used to check the revision unicity for each parameter.  This value will be automatically computed during the create or update. You can ignore it while editing the revision.  # noqa: E501

        :return: The parameter_value_check_sum of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._parameter_value_check_sum

    @parameter_value_check_sum.setter
    def parameter_value_check_sum(self, parameter_value_check_sum):
        """Sets the parameter_value_check_sum of this Revision.

        The checksum of the value used to check the revision unicity for each parameter.  This value will be automatically computed during the create or update. You can ignore it while editing the revision.  # noqa: E501

        :param parameter_value_check_sum: The parameter_value_check_sum of this Revision.  # noqa: E501
        :type: str
        """

        self._parameter_value_check_sum = parameter_value_check_sum

    @property
    def comment(self):
        """Gets the comment of this Revision.  # noqa: E501

        The revision comment  # noqa: E501

        :return: The comment of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Revision.

        The revision comment  # noqa: E501

        :param comment: The comment of this Revision.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def user_name(self):
        """Gets the user_name of this Revision.  # noqa: E501

        The name of the last user having updated the revision  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The user_name of this Revision.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this Revision.

        The name of the last user having updated the revision  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param user_name: The user_name of this Revision.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Revision.  # noqa: E501

        The last utc date time when the properties of the revision have been updated  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Revision.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Revision.

        The last utc date time when the properties of the revision have been updated  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Revision.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def is_new(self):
        """Gets the is_new of this Revision.  # noqa: E501

        Return true if the revision is new  # noqa: E501

        :return: The is_new of this Revision.  # noqa: E501
        :rtype: bool
        """
        return self._is_new

    @is_new.setter
    def is_new(self, is_new):
        """Sets the is_new of this Revision.

        Return true if the revision is new  # noqa: E501

        :param is_new: The is_new of this Revision.  # noqa: E501
        :type: bool
        """

        self._is_new = is_new

    @property
    def data_updated_date(self):
        """Gets the data_updated_date of this Revision.  # noqa: E501

        The last utc date time when the value of the revision have been updated (independently of the others properties)  # noqa: E501

        :return: The data_updated_date of this Revision.  # noqa: E501
        :rtype: datetime
        """
        return self._data_updated_date

    @data_updated_date.setter
    def data_updated_date(self, data_updated_date):
        """Sets the data_updated_date of this Revision.

        The last utc date time when the value of the revision have been updated (independently of the others properties)  # noqa: E501

        :param data_updated_date: The data_updated_date of this Revision.  # noqa: E501
        :type: datetime
        """

        self._data_updated_date = data_updated_date

    @property
    def data_axe_x(self):
        """Gets the data_axe_x of this Revision.  # noqa: E501

        X axis data : filled only when the axis data are embedded inside the parameter definition  # noqa: E501

        :return: The data_axe_x of this Revision.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_x

    @data_axe_x.setter
    def data_axe_x(self, data_axe_x):
        """Sets the data_axe_x of this Revision.

        X axis data : filled only when the axis data are embedded inside the parameter definition  # noqa: E501

        :param data_axe_x: The data_axe_x of this Revision.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_x = data_axe_x

    @property
    def data_axe_y(self):
        """Gets the data_axe_y of this Revision.  # noqa: E501

        Y axis data : filled only when the axis data are embedded inside the parameter definition  # noqa: E501

        :return: The data_axe_y of this Revision.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_y

    @data_axe_y.setter
    def data_axe_y(self, data_axe_y):
        """Sets the data_axe_y of this Revision.

        Y axis data : filled only when the axis data are embedded inside the parameter definition  # noqa: E501

        :param data_axe_y: The data_axe_y of this Revision.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_y = data_axe_y

    @property
    def data_axe_z(self):
        """Gets the data_axe_z of this Revision.  # noqa: E501

        Z axis data : filled only when the axis data are embedded inside the parameter definition  # noqa: E501

        :return: The data_axe_z of this Revision.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_z

    @data_axe_z.setter
    def data_axe_z(self, data_axe_z):
        """Sets the data_axe_z of this Revision.

        Z axis data : filled only when the axis data are embedded inside the parameter definition  # noqa: E501

        :param data_axe_z: The data_axe_z of this Revision.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_z = data_axe_z

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Revision, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Revision):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Revision):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class ModelFieldAuthorization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'concerned_entity_id': 'str',
        'concerned_entity_is_group': 'bool',
        'model_field_id': 'str',
        'can_read': 'bool',
        'can_write': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'concerned_entity_id': 'ConcernedEntityId',
        'concerned_entity_is_group': 'ConcernedEntityIsGroup',
        'model_field_id': 'ModelFieldId',
        'can_read': 'CanRead',
        'can_write': 'CanWrite'
    }

    def __init__(self, id=None, concerned_entity_id=None, concerned_entity_is_group=None, model_field_id=None, can_read=None, can_write=None, _configuration=None):  # noqa: E501
        """ModelFieldAuthorization - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._concerned_entity_id = None
        self._concerned_entity_is_group = None
        self._model_field_id = None
        self._can_read = None
        self._can_write = None
        self.discriminator = None

        self.id = id
        self.concerned_entity_id = concerned_entity_id
        if concerned_entity_is_group is not None:
            self.concerned_entity_is_group = concerned_entity_is_group
        self.model_field_id = model_field_id
        if can_read is not None:
            self.can_read = can_read
        if can_write is not None:
            self.can_write = can_write

    @property
    def id(self):
        """Gets the id of this ModelFieldAuthorization.  # noqa: E501

        The unique model field authorization Id.  # noqa: E501

        :return: The id of this ModelFieldAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelFieldAuthorization.

        The unique model field authorization Id.  # noqa: E501

        :param id: The id of this ModelFieldAuthorization.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def concerned_entity_id(self):
        """Gets the concerned_entity_id of this ModelFieldAuthorization.  # noqa: E501

        The unique id of the concerned entity (user or group).  # noqa: E501

        :return: The concerned_entity_id of this ModelFieldAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._concerned_entity_id

    @concerned_entity_id.setter
    def concerned_entity_id(self, concerned_entity_id):
        """Sets the concerned_entity_id of this ModelFieldAuthorization.

        The unique id of the concerned entity (user or group).  # noqa: E501

        :param concerned_entity_id: The concerned_entity_id of this ModelFieldAuthorization.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and concerned_entity_id is None:
            raise ValueError("Invalid value for `concerned_entity_id`, must not be `None`")  # noqa: E501

        self._concerned_entity_id = concerned_entity_id

    @property
    def concerned_entity_is_group(self):
        """Gets the concerned_entity_is_group of this ModelFieldAuthorization.  # noqa: E501

        Set to True if `ConcernedEntityId` is a group id.  # noqa: E501

        :return: The concerned_entity_is_group of this ModelFieldAuthorization.  # noqa: E501
        :rtype: bool
        """
        return self._concerned_entity_is_group

    @concerned_entity_is_group.setter
    def concerned_entity_is_group(self, concerned_entity_is_group):
        """Sets the concerned_entity_is_group of this ModelFieldAuthorization.

        Set to True if `ConcernedEntityId` is a group id.  # noqa: E501

        :param concerned_entity_is_group: The concerned_entity_is_group of this ModelFieldAuthorization.  # noqa: E501
        :type: bool
        """

        self._concerned_entity_is_group = concerned_entity_is_group

    @property
    def model_field_id(self):
        """Gets the model_field_id of this ModelFieldAuthorization.  # noqa: E501

        The model field id to which this authorization belongs.  # noqa: E501

        :return: The model_field_id of this ModelFieldAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._model_field_id

    @model_field_id.setter
    def model_field_id(self, model_field_id):
        """Sets the model_field_id of this ModelFieldAuthorization.

        The model field id to which this authorization belongs.  # noqa: E501

        :param model_field_id: The model_field_id of this ModelFieldAuthorization.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and model_field_id is None:
            raise ValueError("Invalid value for `model_field_id`, must not be `None`")  # noqa: E501

        self._model_field_id = model_field_id

    @property
    def can_read(self):
        """Gets the can_read of this ModelFieldAuthorization.  # noqa: E501

        Set to True to allow the user/group to read the model field data.  # noqa: E501

        :return: The can_read of this ModelFieldAuthorization.  # noqa: E501
        :rtype: bool
        """
        return self._can_read

    @can_read.setter
    def can_read(self, can_read):
        """Sets the can_read of this ModelFieldAuthorization.

        Set to True to allow the user/group to read the model field data.  # noqa: E501

        :param can_read: The can_read of this ModelFieldAuthorization.  # noqa: E501
        :type: bool
        """

        self._can_read = can_read

    @property
    def can_write(self):
        """Gets the can_write of this ModelFieldAuthorization.  # noqa: E501

        Set to True to allow the user/group to write into the model field data.  # noqa: E501

        :return: The can_write of this ModelFieldAuthorization.  # noqa: E501
        :rtype: bool
        """
        return self._can_write

    @can_write.setter
    def can_write(self, can_write):
        """Sets the can_write of this ModelFieldAuthorization.

        Set to True to allow the user/group to write into the model field data.  # noqa: E501

        :param can_write: The can_write of this ModelFieldAuthorization.  # noqa: E501
        :type: bool
        """

        self._can_write = can_write

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelFieldAuthorization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelFieldAuthorization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelFieldAuthorization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class TeamDBViewApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def team_db_view_get_fields_in_view(self, view_id, **kwargs):  # noqa: E501
        """Get the list of all fields contained inside a view  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_fields_in_view(view_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view_id: The view id for which you want the fields list (required)
        :param bool find_in_subviews: True if you want to include the fields that are contained in the subviews
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_view_get_fields_in_view_with_http_info(view_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_view_get_fields_in_view_with_http_info(view_id, **kwargs)  # noqa: E501
            return data

    def team_db_view_get_fields_in_view_with_http_info(self, view_id, **kwargs):  # noqa: E501
        """Get the list of all fields contained inside a view  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_fields_in_view_with_http_info(view_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view_id: The view id for which you want the fields list (required)
        :param bool find_in_subviews: True if you want to include the fields that are contained in the subviews
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['view_id', 'find_in_subviews']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_view_get_fields_in_view" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'view_id' is set
        if self.api_client.client_side_validation and ('view_id' not in params or
                                                       params['view_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `view_id` when calling `team_db_view_get_fields_in_view`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'view_id' in params:
            query_params.append(('viewId', params['view_id']))  # noqa: E501
        if 'find_in_subviews' in params:
            query_params.append(('findInSubviews', params['find_in_subviews']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/fieldsinsideview', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_view_get_layouts(self, **kwargs):  # noqa: E501
        """Get the list of all layouts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_layouts(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_view_get_layouts_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.team_db_view_get_layouts_with_http_info(**kwargs)  # noqa: E501
            return data

    def team_db_view_get_layouts_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all layouts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_layouts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_view_get_layouts" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/layouts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_view_get_views(self, **kwargs):  # noqa: E501
        """Get the list of all views you are allowed to access  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_views(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_view_get_views_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.team_db_view_get_views_with_http_info(**kwargs)  # noqa: E501
            return data

    def team_db_view_get_views_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all views you are allowed to access  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_views_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_view_get_views" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/views', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_view_get_views_from_layout(self, layout_id, **kwargs):  # noqa: E501
        """Get the list of all TeamDB views displayed in a layout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_views_from_layout(layout_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str layout_id: The TeamDB Layout unique identifier (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_view_get_views_from_layout_with_http_info(layout_id, **kwargs)  # noqa: E501
        else:
            (data) = self.team_db_view_get_views_from_layout_with_http_info(layout_id, **kwargs)  # noqa: E501
            return data

    def team_db_view_get_views_from_layout_with_http_info(self, layout_id, **kwargs):  # noqa: E501
        """Get the list of all TeamDB views displayed in a layout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_views_from_layout_with_http_info(layout_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str layout_id: The TeamDB Layout unique identifier (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['layout_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_view_get_views_from_layout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'layout_id' is set
        if self.api_client.client_side_validation and ('layout_id' not in params or
                                                       params['layout_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `layout_id` when calling `team_db_view_get_views_from_layout`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'layout_id' in params:
            path_params['layoutId'] = params['layout_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/layout/{layoutId}/views', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def team_db_view_get_views_using_field(self, **kwargs):  # noqa: E501
        """Get the list of all views using a given modelfield  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_views_using_field(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_id: The field id for which you want the views list
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.team_db_view_get_views_using_field_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.team_db_view_get_views_using_field_with_http_info(**kwargs)  # noqa: E501
            return data

    def team_db_view_get_views_using_field_with_http_info(self, **kwargs):  # noqa: E501
        """Get the list of all views using a given modelfield  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.team_db_view_get_views_using_field_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_id: The field id for which you want the views list
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['field_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method team_db_view_get_views_using_field" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'field_id' in params:
            query_params.append(('fieldId', params['field_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/viewusingfield', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class CompareResultDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reference': 'str',
        'assembly_a_detail': 'CompareResult',
        'assembly_b_detail': 'CompareResult',
        'diff_type': 'str'
    }

    attribute_map = {
        'reference': 'Reference',
        'assembly_a_detail': 'AssemblyADetail',
        'assembly_b_detail': 'AssemblyBDetail',
        'diff_type': 'DiffType'
    }

    def __init__(self, reference=None, assembly_a_detail=None, assembly_b_detail=None, diff_type=None, _configuration=None):  # noqa: E501
        """CompareResultDetail - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._reference = None
        self._assembly_a_detail = None
        self._assembly_b_detail = None
        self._diff_type = None
        self.discriminator = None

        if reference is not None:
            self.reference = reference
        if assembly_a_detail is not None:
            self.assembly_a_detail = assembly_a_detail
        if assembly_b_detail is not None:
            self.assembly_b_detail = assembly_b_detail
        if diff_type is not None:
            self.diff_type = diff_type

    @property
    def reference(self):
        """Gets the reference of this CompareResultDetail.  # noqa: E501

        Parameter reference  # noqa: E501

        :return: The reference of this CompareResultDetail.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this CompareResultDetail.

        Parameter reference  # noqa: E501

        :param reference: The reference of this CompareResultDetail.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def assembly_a_detail(self):
        """Gets the assembly_a_detail of this CompareResultDetail.  # noqa: E501


        :return: The assembly_a_detail of this CompareResultDetail.  # noqa: E501
        :rtype: CompareResult
        """
        return self._assembly_a_detail

    @assembly_a_detail.setter
    def assembly_a_detail(self, assembly_a_detail):
        """Sets the assembly_a_detail of this CompareResultDetail.


        :param assembly_a_detail: The assembly_a_detail of this CompareResultDetail.  # noqa: E501
        :type: CompareResult
        """

        self._assembly_a_detail = assembly_a_detail

    @property
    def assembly_b_detail(self):
        """Gets the assembly_b_detail of this CompareResultDetail.  # noqa: E501


        :return: The assembly_b_detail of this CompareResultDetail.  # noqa: E501
        :rtype: CompareResult
        """
        return self._assembly_b_detail

    @assembly_b_detail.setter
    def assembly_b_detail(self, assembly_b_detail):
        """Sets the assembly_b_detail of this CompareResultDetail.


        :param assembly_b_detail: The assembly_b_detail of this CompareResultDetail.  # noqa: E501
        :type: CompareResult
        """

        self._assembly_b_detail = assembly_b_detail

    @property
    def diff_type(self):
        """Gets the diff_type of this CompareResultDetail.  # noqa: E501

        The difference type detected between A and B  # noqa: E501

        :return: The diff_type of this CompareResultDetail.  # noqa: E501
        :rtype: str
        """
        return self._diff_type

    @diff_type.setter
    def diff_type(self, diff_type):
        """Sets the diff_type of this CompareResultDetail.

        The difference type detected between A and B  # noqa: E501

        :param diff_type: The diff_type of this CompareResultDetail.  # noqa: E501
        :type: str
        """
        allowed_values = ["A_Missing", "B_Missing", "Difference"]  # noqa: E501
        if (self._configuration.client_side_validation and
                diff_type not in allowed_values):
            raise ValueError(
                "Invalid value for `diff_type` ({0}), must be one of {1}"  # noqa: E501
                .format(diff_type, allowed_values)
            )

        self._diff_type = diff_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompareResultDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompareResultDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompareResultDetail):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class ValueFieldApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def value_field_get_item_values(self, item_value_keys, **kwargs):  # noqa: E501
        """Get a list of value fields, revision editors and revision selectors via a model field unique id and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_get_item_values(item_value_keys, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ItemValueKey] item_value_keys: The list of keys (model field / parent entity) for which you want to get the values (required)
        :return: list[ItemValue]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.value_field_get_item_values_with_http_info(item_value_keys, **kwargs)  # noqa: E501
        else:
            (data) = self.value_field_get_item_values_with_http_info(item_value_keys, **kwargs)  # noqa: E501
            return data

    def value_field_get_item_values_with_http_info(self, item_value_keys, **kwargs):  # noqa: E501
        """Get a list of value fields, revision editors and revision selectors via a model field unique id and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_get_item_values_with_http_info(item_value_keys, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ItemValueKey] item_value_keys: The list of keys (model field / parent entity) for which you want to get the values (required)
        :return: list[ItemValue]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_value_keys']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method value_field_get_item_values" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_value_keys' is set
        if self.api_client.client_side_validation and ('item_value_keys' not in params or
                                                       params['item_value_keys'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `item_value_keys` when calling `value_field_get_item_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'item_value_keys' in params:
            body_params = params['item_value_keys']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/valuefields', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ItemValue]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def value_field_get_value_field(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get a value field via a model field unique id and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_get_value_field(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the value field (required)
        :param str parent_item_id: The parent item id for which you want to get the value field (required)
        :param int row_id: The row 0 based index of the cell for which you want the value. The Row headers are included.
        :param int col_id: The column 0 based index of the cell for which you want the value
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.value_field_get_value_field_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.value_field_get_value_field_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
            return data

    def value_field_get_value_field_with_http_info(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get a value field via a model field unique id and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_get_value_field_with_http_info(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the value field (required)
        :param str parent_item_id: The parent item id for which you want to get the value field (required)
        :param int row_id: The row 0 based index of the cell for which you want the value. The Row headers are included.
        :param int col_id: The column 0 based index of the cell for which you want the value
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id', 'row_id', 'col_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method value_field_get_value_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `value_field_get_value_field`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `value_field_get_value_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501
        if 'row_id' in params:
            query_params.append(('rowId', params['row_id']))  # noqa: E501
        if 'col_id' in params:
            query_params.append(('colId', params['col_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/valuefield', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def value_field_get_value_field(self, field_name, field_type, parent_item_id, **kwargs):  # noqa: E501
        """Retrieve the list of all values of a modelField  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_get_value_field(field_name, field_type, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_name: The name of the field for which you are looking for values (required)
        :param str field_type: The type of modelField (event, car,...) (required)
        :param str parent_item_id: Id of the parent itembase (required)
        :return: list[object]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.value_field_get_value_field_with_http_info(field_name, field_type, parent_item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.value_field_get_value_field_with_http_info(field_name, field_type, parent_item_id, **kwargs)  # noqa: E501
            return data

    def value_field_get_value_field_with_http_info(self, field_name, field_type, parent_item_id, **kwargs):  # noqa: E501
        """Retrieve the list of all values of a modelField  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_get_value_field_with_http_info(field_name, field_type, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_name: The name of the field for which you are looking for values (required)
        :param str field_type: The type of modelField (event, car,...) (required)
        :param str parent_item_id: Id of the parent itembase (required)
        :return: list[object]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['field_name', 'field_type', 'parent_item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method value_field_get_value_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'field_name' is set
        if self.api_client.client_side_validation and ('field_name' not in params or
                                                       params['field_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `field_name` when calling `value_field_get_value_field`")  # noqa: E501
        # verify the required parameter 'field_type' is set
        if self.api_client.client_side_validation and ('field_type' not in params or
                                                       params['field_type'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `field_type` when calling `value_field_get_value_field`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `value_field_get_value_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'field_name' in params:
            path_params['fieldName'] = params['field_name']  # noqa: E501
        if 'field_type' in params:
            path_params['fieldType'] = params['field_type']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{fieldName}/fieldType/{fieldType}/valuefield', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[object]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def value_field_set_item_values(self, item_values, **kwargs):  # noqa: E501
        """Set a list of items value fields, revision editors and revision selectors via a model field unique id and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_set_item_values(item_values, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ItemValue] item_values: The list of values you want to set (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.value_field_set_item_values_with_http_info(item_values, **kwargs)  # noqa: E501
        else:
            (data) = self.value_field_set_item_values_with_http_info(item_values, **kwargs)  # noqa: E501
            return data

    def value_field_set_item_values_with_http_info(self, item_values, **kwargs):  # noqa: E501
        """Set a list of items value fields, revision editors and revision selectors via a model field unique id and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_set_item_values_with_http_info(item_values, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ItemValue] item_values: The list of values you want to set (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_values']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method value_field_set_item_values" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_values' is set
        if self.api_client.client_side_validation and ('item_values' not in params or
                                                       params['item_values'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `item_values` when calling `value_field_set_item_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'item_values' in params:
            body_params = params['item_values']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/valuefields', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def value_field_set_value_field(self, model_field_id, parent_item_id, value, **kwargs):  # noqa: E501
        """Set a value field via a model field unique id and a parent entity unique id.  To update a RevisionEditor call POST tracksideapi/v1/RevisionEditorValue method from RevisionEditorSelector API instead  To update a RevisionSelector call POST tracksideapi/v1/RevisionSelectorValue method from RevisionEditorSelector API instead  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_set_value_field(model_field_id, parent_item_id, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the value field (required)
        :param str parent_item_id: The parent item id for which you want to get the value field (required)
        :param object value: The value to set in the value field. -Timespan, enter a double value in seconds 125.333 -> 02:05.333. -DateTime, use the following format 2019-02-18T18:14:32.930Z. -Image, enter the path to the file with the following format C:\\\\\\Users\\\\\\MyUser\\\\\\Downloads\\\\\\MyImage.png (note the double \\\\) (required)
        :return: ValueField
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.value_field_set_value_field_with_http_info(model_field_id, parent_item_id, value, **kwargs)  # noqa: E501
        else:
            (data) = self.value_field_set_value_field_with_http_info(model_field_id, parent_item_id, value, **kwargs)  # noqa: E501
            return data

    def value_field_set_value_field_with_http_info(self, model_field_id, parent_item_id, value, **kwargs):  # noqa: E501
        """Set a value field via a model field unique id and a parent entity unique id.  To update a RevisionEditor call POST tracksideapi/v1/RevisionEditorValue method from RevisionEditorSelector API instead  To update a RevisionSelector call POST tracksideapi/v1/RevisionSelectorValue method from RevisionEditorSelector API instead  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.value_field_set_value_field_with_http_info(model_field_id, parent_item_id, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the value field (required)
        :param str parent_item_id: The parent item id for which you want to get the value field (required)
        :param object value: The value to set in the value field. -Timespan, enter a double value in seconds 125.333 -> 02:05.333. -DateTime, use the following format 2019-02-18T18:14:32.930Z. -Image, enter the path to the file with the following format C:\\\\\\Users\\\\\\MyUser\\\\\\Downloads\\\\\\MyImage.png (note the double \\\\) (required)
        :return: ValueField
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id', 'value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method value_field_set_value_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `value_field_set_value_field`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `value_field_set_value_field`")  # noqa: E501
        # verify the required parameter 'value' is set
        if self.api_client.client_side_validation and ('value' not in params or
                                                       params['value'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `value` when calling `value_field_set_value_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/valuefield', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ValueField',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Tire(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'tire_serial': 'str',
        'comment': 'str',
        'initial_km': 'int',
        'rim_serial': 'str',
        'type_tire_id': 'str',
        'event_id': 'str',
        'km_basic_forward_total': 'float',
        'km_basic_reverse_total': 'float',
        'km_real_forward_total': 'float',
        'km_real_reverse_total': 'float',
        'km_basic_overall': 'float',
        'km_real_overall': 'float',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'cold_pressure': 'float',
        'lap_count_forward_total': 'int',
        'lap_count_reverse_total': 'int',
        'bleed_adjust': 'list[BleedAdjustment]',
        'status': 'str',
        'weight': 'float',
        'return_weight': 'float',
        'initial_sliding_energy': 'float',
        'sliding_energy_total': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'tire_serial': 'TireSerial',
        'comment': 'Comment',
        'initial_km': 'InitialKm',
        'rim_serial': 'RimSerial',
        'type_tire_id': 'TypeTireId',
        'event_id': 'EventId',
        'km_basic_forward_total': 'KmBasicForwardTotal',
        'km_basic_reverse_total': 'KmBasicReverseTotal',
        'km_real_forward_total': 'KmRealForwardTotal',
        'km_real_reverse_total': 'KmRealReverseTotal',
        'km_basic_overall': 'KmBasicOverall',
        'km_real_overall': 'KmRealOverall',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'cold_pressure': 'ColdPressure',
        'lap_count_forward_total': 'LapCountForwardTotal',
        'lap_count_reverse_total': 'LapCountReverseTotal',
        'bleed_adjust': 'BleedAdjust',
        'status': 'Status',
        'weight': 'Weight',
        'return_weight': 'ReturnWeight',
        'initial_sliding_energy': 'InitialSlidingEnergy',
        'sliding_energy_total': 'SlidingEnergyTotal'
    }

    def __init__(self, id=None, name=None, tire_serial=None, comment=None, initial_km=None, rim_serial=None, type_tire_id=None, event_id=None, km_basic_forward_total=None, km_basic_reverse_total=None, km_real_forward_total=None, km_real_reverse_total=None, km_basic_overall=None, km_real_overall=None, last_update_date_utc=None, last_update_user=None, cold_pressure=None, lap_count_forward_total=None, lap_count_reverse_total=None, bleed_adjust=None, status=None, weight=None, return_weight=None, initial_sliding_energy=None, sliding_energy_total=None, _configuration=None):  # noqa: E501
        """Tire - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._tire_serial = None
        self._comment = None
        self._initial_km = None
        self._rim_serial = None
        self._type_tire_id = None
        self._event_id = None
        self._km_basic_forward_total = None
        self._km_basic_reverse_total = None
        self._km_real_forward_total = None
        self._km_real_reverse_total = None
        self._km_basic_overall = None
        self._km_real_overall = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._cold_pressure = None
        self._lap_count_forward_total = None
        self._lap_count_reverse_total = None
        self._bleed_adjust = None
        self._status = None
        self._weight = None
        self._return_weight = None
        self._initial_sliding_energy = None
        self._sliding_energy_total = None
        self.discriminator = None

        self.id = id
        self.name = name
        if tire_serial is not None:
            self.tire_serial = tire_serial
        if comment is not None:
            self.comment = comment
        if initial_km is not None:
            self.initial_km = initial_km
        if rim_serial is not None:
            self.rim_serial = rim_serial
        self.type_tire_id = type_tire_id
        self.event_id = event_id
        if km_basic_forward_total is not None:
            self.km_basic_forward_total = km_basic_forward_total
        if km_basic_reverse_total is not None:
            self.km_basic_reverse_total = km_basic_reverse_total
        if km_real_forward_total is not None:
            self.km_real_forward_total = km_real_forward_total
        if km_real_reverse_total is not None:
            self.km_real_reverse_total = km_real_reverse_total
        if km_basic_overall is not None:
            self.km_basic_overall = km_basic_overall
        if km_real_overall is not None:
            self.km_real_overall = km_real_overall
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if cold_pressure is not None:
            self.cold_pressure = cold_pressure
        if lap_count_forward_total is not None:
            self.lap_count_forward_total = lap_count_forward_total
        if lap_count_reverse_total is not None:
            self.lap_count_reverse_total = lap_count_reverse_total
        if bleed_adjust is not None:
            self.bleed_adjust = bleed_adjust
        if status is not None:
            self.status = status
        if weight is not None:
            self.weight = weight
        if return_weight is not None:
            self.return_weight = return_weight
        if initial_sliding_energy is not None:
            self.initial_sliding_energy = initial_sliding_energy
        if sliding_energy_total is not None:
            self.sliding_energy_total = sliding_energy_total

    @property
    def id(self):
        """Gets the id of this Tire.  # noqa: E501

        Tire unique identifier  # noqa: E501

        :return: The id of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Tire.

        Tire unique identifier  # noqa: E501

        :param id: The id of this Tire.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Tire.  # noqa: E501

        Tire name  # noqa: E501

        :return: The name of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Tire.

        Tire name  # noqa: E501

        :param name: The name of this Tire.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def tire_serial(self):
        """Gets the tire_serial of this Tire.  # noqa: E501

        Tire serial number  # noqa: E501

        :return: The tire_serial of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._tire_serial

    @tire_serial.setter
    def tire_serial(self, tire_serial):
        """Sets the tire_serial of this Tire.

        Tire serial number  # noqa: E501

        :param tire_serial: The tire_serial of this Tire.  # noqa: E501
        :type: str
        """

        self._tire_serial = tire_serial

    @property
    def comment(self):
        """Gets the comment of this Tire.  # noqa: E501

        Tire comments  # noqa: E501

        :return: The comment of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Tire.

        Tire comments  # noqa: E501

        :param comment: The comment of this Tire.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def initial_km(self):
        """Gets the initial_km of this Tire.  # noqa: E501

        Initial tire km  # noqa: E501

        :return: The initial_km of this Tire.  # noqa: E501
        :rtype: int
        """
        return self._initial_km

    @initial_km.setter
    def initial_km(self, initial_km):
        """Sets the initial_km of this Tire.

        Initial tire km  # noqa: E501

        :param initial_km: The initial_km of this Tire.  # noqa: E501
        :type: int
        """

        self._initial_km = initial_km

    @property
    def rim_serial(self):
        """Gets the rim_serial of this Tire.  # noqa: E501

        Rim serial number  # noqa: E501

        :return: The rim_serial of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._rim_serial

    @rim_serial.setter
    def rim_serial(self, rim_serial):
        """Sets the rim_serial of this Tire.

        Rim serial number  # noqa: E501

        :param rim_serial: The rim_serial of this Tire.  # noqa: E501
        :type: str
        """

        self._rim_serial = rim_serial

    @property
    def type_tire_id(self):
        """Gets the type_tire_id of this Tire.  # noqa: E501

        Unique identifier of the Tire rubber type. You must choose an Id from the TeamDBListItem collection corresponding to the TeamDBList named TypeTireRubber.  # noqa: E501

        :return: The type_tire_id of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._type_tire_id

    @type_tire_id.setter
    def type_tire_id(self, type_tire_id):
        """Sets the type_tire_id of this Tire.

        Unique identifier of the Tire rubber type. You must choose an Id from the TeamDBListItem collection corresponding to the TeamDBList named TypeTireRubber.  # noqa: E501

        :param type_tire_id: The type_tire_id of this Tire.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type_tire_id is None:
            raise ValueError("Invalid value for `type_tire_id`, must not be `None`")  # noqa: E501

        self._type_tire_id = type_tire_id

    @property
    def event_id(self):
        """Gets the event_id of this Tire.  # noqa: E501

        Unique identifier corresponding to the event to which the tire belongs  # noqa: E501

        :return: The event_id of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this Tire.

        Unique identifier corresponding to the event to which the tire belongs  # noqa: E501

        :param event_id: The event_id of this Tire.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and event_id is None:
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def km_basic_forward_total(self):
        """Gets the km_basic_forward_total of this Tire.  # noqa: E501

        Total distance performed by the tire mounted in the forward direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The km_basic_forward_total of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._km_basic_forward_total

    @km_basic_forward_total.setter
    def km_basic_forward_total(self, km_basic_forward_total):
        """Sets the km_basic_forward_total of this Tire.

        Total distance performed by the tire mounted in the forward direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param km_basic_forward_total: The km_basic_forward_total of this Tire.  # noqa: E501
        :type: float
        """

        self._km_basic_forward_total = km_basic_forward_total

    @property
    def km_basic_reverse_total(self):
        """Gets the km_basic_reverse_total of this Tire.  # noqa: E501

        Total distance performed by the tire mounted in the reverse direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The km_basic_reverse_total of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._km_basic_reverse_total

    @km_basic_reverse_total.setter
    def km_basic_reverse_total(self, km_basic_reverse_total):
        """Sets the km_basic_reverse_total of this Tire.

        Total distance performed by the tire mounted in the reverse direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param km_basic_reverse_total: The km_basic_reverse_total of this Tire.  # noqa: E501
        :type: float
        """

        self._km_basic_reverse_total = km_basic_reverse_total

    @property
    def km_real_forward_total(self):
        """Gets the km_real_forward_total of this Tire.  # noqa: E501

        Total real distance performed lap by lap by the tire mounted in the forward direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The km_real_forward_total of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._km_real_forward_total

    @km_real_forward_total.setter
    def km_real_forward_total(self, km_real_forward_total):
        """Sets the km_real_forward_total of this Tire.

        Total real distance performed lap by lap by the tire mounted in the forward direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param km_real_forward_total: The km_real_forward_total of this Tire.  # noqa: E501
        :type: float
        """

        self._km_real_forward_total = km_real_forward_total

    @property
    def km_real_reverse_total(self):
        """Gets the km_real_reverse_total of this Tire.  # noqa: E501

        Total real distance performed lap by lap by the tire mounted in the reverse direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The km_real_reverse_total of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._km_real_reverse_total

    @km_real_reverse_total.setter
    def km_real_reverse_total(self, km_real_reverse_total):
        """Sets the km_real_reverse_total of this Tire.

        Total real distance performed lap by lap by the tire mounted in the reverse direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param km_real_reverse_total: The km_real_reverse_total of this Tire.  # noqa: E501
        :type: float
        """

        self._km_real_reverse_total = km_real_reverse_total

    @property
    def km_basic_overall(self):
        """Gets the km_basic_overall of this Tire.  # noqa: E501

        Global distance performed by the tire (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The km_basic_overall of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._km_basic_overall

    @km_basic_overall.setter
    def km_basic_overall(self, km_basic_overall):
        """Sets the km_basic_overall of this Tire.

        Global distance performed by the tire (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param km_basic_overall: The km_basic_overall of this Tire.  # noqa: E501
        :type: float
        """

        self._km_basic_overall = km_basic_overall

    @property
    def km_real_overall(self):
        """Gets the km_real_overall of this Tire.  # noqa: E501

        Global real distance performed by the tire (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The km_real_overall of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._km_real_overall

    @km_real_overall.setter
    def km_real_overall(self, km_real_overall):
        """Sets the km_real_overall of this Tire.

        Global real distance performed by the tire (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param km_real_overall: The km_real_overall of this Tire.  # noqa: E501
        :type: float
        """

        self._km_real_overall = km_real_overall

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Tire.  # noqa: E501

        Last updated utc date time. This field is automatically filled by the system.  # noqa: E501

        :return: The last_update_date_utc of this Tire.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Tire.

        Last updated utc date time. This field is automatically filled by the system.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Tire.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Tire.  # noqa: E501

        Name of the last user who updated the data. This field is automatically filled by the system.  # noqa: E501

        :return: The last_update_user of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Tire.

        Name of the last user who updated the data. This field is automatically filled by the system.  # noqa: E501

        :param last_update_user: The last_update_user of this Tire.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def cold_pressure(self):
        """Gets the cold_pressure of this Tire.  # noqa: E501

        The cold pressure value  # noqa: E501

        :return: The cold_pressure of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._cold_pressure

    @cold_pressure.setter
    def cold_pressure(self, cold_pressure):
        """Sets the cold_pressure of this Tire.

        The cold pressure value  # noqa: E501

        :param cold_pressure: The cold_pressure of this Tire.  # noqa: E501
        :type: float
        """

        self._cold_pressure = cold_pressure

    @property
    def lap_count_forward_total(self):
        """Gets the lap_count_forward_total of this Tire.  # noqa: E501

        Total lap count performed by the tire mounted in the forward direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The lap_count_forward_total of this Tire.  # noqa: E501
        :rtype: int
        """
        return self._lap_count_forward_total

    @lap_count_forward_total.setter
    def lap_count_forward_total(self, lap_count_forward_total):
        """Sets the lap_count_forward_total of this Tire.

        Total lap count performed by the tire mounted in the forward direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param lap_count_forward_total: The lap_count_forward_total of this Tire.  # noqa: E501
        :type: int
        """

        self._lap_count_forward_total = lap_count_forward_total

    @property
    def lap_count_reverse_total(self):
        """Gets the lap_count_reverse_total of this Tire.  # noqa: E501

        Total lap count performed by the tire mounted in the reverse direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :return: The lap_count_reverse_total of this Tire.  # noqa: E501
        :rtype: int
        """
        return self._lap_count_reverse_total

    @lap_count_reverse_total.setter
    def lap_count_reverse_total(self, lap_count_reverse_total):
        """Sets the lap_count_reverse_total of this Tire.

        Total lap count performed by the tire mounted in the reverse direction (readonly).  This field is automatically computed by the system.  # noqa: E501

        :param lap_count_reverse_total: The lap_count_reverse_total of this Tire.  # noqa: E501
        :type: int
        """

        self._lap_count_reverse_total = lap_count_reverse_total

    @property
    def bleed_adjust(self):
        """Gets the bleed_adjust of this Tire.  # noqa: E501

        the collection of bleed ajustements  # noqa: E501

        :return: The bleed_adjust of this Tire.  # noqa: E501
        :rtype: list[BleedAdjustment]
        """
        return self._bleed_adjust

    @bleed_adjust.setter
    def bleed_adjust(self, bleed_adjust):
        """Sets the bleed_adjust of this Tire.

        the collection of bleed ajustements  # noqa: E501

        :param bleed_adjust: The bleed_adjust of this Tire.  # noqa: E501
        :type: list[BleedAdjustment]
        """

        self._bleed_adjust = bleed_adjust

    @property
    def status(self):
        """Gets the status of this Tire.  # noqa: E501

        The tire status (value from the TireStatus enumeration)  # noqa: E501

        :return: The status of this Tire.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Tire.

        The tire status (value from the TireStatus enumeration)  # noqa: E501

        :param status: The status of this Tire.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotMounted", "Scrapped", "Mounted", "Heating", "Hot", "OnCar"]  # noqa: E501
        if (self._configuration.client_side_validation and
                status not in allowed_values):
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def weight(self):
        """Gets the weight of this Tire.  # noqa: E501

        The tire weight  # noqa: E501

        :return: The weight of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this Tire.

        The tire weight  # noqa: E501

        :param weight: The weight of this Tire.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def return_weight(self):
        """Gets the return_weight of this Tire.  # noqa: E501

        The tire return weight  # noqa: E501

        :return: The return_weight of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._return_weight

    @return_weight.setter
    def return_weight(self, return_weight):
        """Sets the return_weight of this Tire.

        The tire return weight  # noqa: E501

        :param return_weight: The return_weight of this Tire.  # noqa: E501
        :type: float
        """

        self._return_weight = return_weight

    @property
    def initial_sliding_energy(self):
        """Gets the initial_sliding_energy of this Tire.  # noqa: E501

        Energie initial du pneu  # noqa: E501

        :return: The initial_sliding_energy of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._initial_sliding_energy

    @initial_sliding_energy.setter
    def initial_sliding_energy(self, initial_sliding_energy):
        """Sets the initial_sliding_energy of this Tire.

        Energie initial du pneu  # noqa: E501

        :param initial_sliding_energy: The initial_sliding_energy of this Tire.  # noqa: E501
        :type: float
        """

        self._initial_sliding_energy = initial_sliding_energy

    @property
    def sliding_energy_total(self):
        """Gets the sliding_energy_total of this Tire.  # noqa: E501

        Energie total du pneu  # noqa: E501

        :return: The sliding_energy_total of this Tire.  # noqa: E501
        :rtype: float
        """
        return self._sliding_energy_total

    @sliding_energy_total.setter
    def sliding_energy_total(self, sliding_energy_total):
        """Sets the sliding_energy_total of this Tire.

        Energie total du pneu  # noqa: E501

        :param sliding_energy_total: The sliding_energy_total of this Tire.  # noqa: E501
        :type: float
        """

        self._sliding_energy_total = sliding_energy_total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tire, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tire):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Tire):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Calibration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'reference': 'str',
        'data': 'list[object]',
        'data_type': 'str',
        'nx': 'int',
        'ny': 'int',
        'nz': 'int',
        'axe_x': 'str',
        'axe_y': 'str',
        'axe_z': 'str',
        'calibration_type': 'str',
        'groupe_path': 'str',
        'unit': 'str',
        'data_axe_x': 'list[float]',
        'data_axe_y': 'list[float]',
        'data_axe_z': 'list[float]',
        'is_axe': 'bool',
        'group_full_path': 'str',
        'string_format': 'str',
        'upper_limit': 'float',
        'lower_limit': 'float',
        'read_only': 'bool'
    }

    attribute_map = {
        'name': 'Name',
        'description': 'Description',
        'reference': 'Reference',
        'data': 'Data',
        'data_type': 'DataType',
        'nx': 'NX',
        'ny': 'NY',
        'nz': 'NZ',
        'axe_x': 'AxeX',
        'axe_y': 'AxeY',
        'axe_z': 'AxeZ',
        'calibration_type': 'CalibrationType',
        'groupe_path': 'GroupePath',
        'unit': 'Unit',
        'data_axe_x': 'DataAxeX',
        'data_axe_y': 'DataAxeY',
        'data_axe_z': 'DataAxeZ',
        'is_axe': 'IsAxe',
        'group_full_path': 'GroupFullPath',
        'string_format': 'StringFormat',
        'upper_limit': 'UpperLimit',
        'lower_limit': 'LowerLimit',
        'read_only': 'ReadOnly'
    }

    def __init__(self, name=None, description=None, reference=None, data=None, data_type=None, nx=None, ny=None, nz=None, axe_x=None, axe_y=None, axe_z=None, calibration_type=None, groupe_path=None, unit=None, data_axe_x=None, data_axe_y=None, data_axe_z=None, is_axe=None, group_full_path=None, string_format=None, upper_limit=None, lower_limit=None, read_only=None, _configuration=None):  # noqa: E501
        """Calibration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._description = None
        self._reference = None
        self._data = None
        self._data_type = None
        self._nx = None
        self._ny = None
        self._nz = None
        self._axe_x = None
        self._axe_y = None
        self._axe_z = None
        self._calibration_type = None
        self._groupe_path = None
        self._unit = None
        self._data_axe_x = None
        self._data_axe_y = None
        self._data_axe_z = None
        self._is_axe = None
        self._group_full_path = None
        self._string_format = None
        self._upper_limit = None
        self._lower_limit = None
        self._read_only = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if reference is not None:
            self.reference = reference
        if data is not None:
            self.data = data
        if data_type is not None:
            self.data_type = data_type
        if nx is not None:
            self.nx = nx
        if ny is not None:
            self.ny = ny
        if nz is not None:
            self.nz = nz
        if axe_x is not None:
            self.axe_x = axe_x
        if axe_y is not None:
            self.axe_y = axe_y
        if axe_z is not None:
            self.axe_z = axe_z
        if calibration_type is not None:
            self.calibration_type = calibration_type
        if groupe_path is not None:
            self.groupe_path = groupe_path
        if unit is not None:
            self.unit = unit
        if data_axe_x is not None:
            self.data_axe_x = data_axe_x
        if data_axe_y is not None:
            self.data_axe_y = data_axe_y
        if data_axe_z is not None:
            self.data_axe_z = data_axe_z
        if is_axe is not None:
            self.is_axe = is_axe
        if group_full_path is not None:
            self.group_full_path = group_full_path
        if string_format is not None:
            self.string_format = string_format
        if upper_limit is not None:
            self.upper_limit = upper_limit
        if lower_limit is not None:
            self.lower_limit = lower_limit
        if read_only is not None:
            self.read_only = read_only

    @property
    def name(self):
        """Gets the name of this Calibration.  # noqa: E501

        The parameter name  # noqa: E501

        :return: The name of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Calibration.

        The parameter name  # noqa: E501

        :param name: The name of this Calibration.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this Calibration.  # noqa: E501

        The parameter description  # noqa: E501

        :return: The description of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Calibration.

        The parameter description  # noqa: E501

        :param description: The description of this Calibration.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def reference(self):
        """Gets the reference of this Calibration.  # noqa: E501

        The parameter reference in the external system  # noqa: E501

        :return: The reference of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Calibration.

        The parameter reference in the external system  # noqa: E501

        :param reference: The reference of this Calibration.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def data(self):
        """Gets the data of this Calibration.  # noqa: E501

        The parameter data.  Depending on the parameter definition the value can be a single value or 2D value or 3D.  For this reason, the Value is represented as a 3 dimensionals JSON array.  The value type can be a string or double depending on the parameter.  For this reason, you have to serialize the value with invariant culture format.  Decimal separator must be the point. The coma is use to separate the elements inside the array.  Single Value sample : [[[0.7]]]  1D Value sample : [[[0.0]],[[0.1]],[[0.2]]]  2D Value sample : [[[1.0],[1.0],[1.0]], [[1.0],[1.0],[1.0],[1.0]]]  # noqa: E501

        :return: The data of this Calibration.  # noqa: E501
        :rtype: list[object]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this Calibration.

        The parameter data.  Depending on the parameter definition the value can be a single value or 2D value or 3D.  For this reason, the Value is represented as a 3 dimensionals JSON array.  The value type can be a string or double depending on the parameter.  For this reason, you have to serialize the value with invariant culture format.  Decimal separator must be the point. The coma is use to separate the elements inside the array.  Single Value sample : [[[0.7]]]  1D Value sample : [[[0.0]],[[0.1]],[[0.2]]]  2D Value sample : [[[1.0],[1.0],[1.0]], [[1.0],[1.0],[1.0],[1.0]]]  # noqa: E501

        :param data: The data of this Calibration.  # noqa: E501
        :type: list[object]
        """

        self._data = data

    @property
    def data_type(self):
        """Gets the data_type of this Calibration.  # noqa: E501

        The data type  None, Byte, SByte, Word, SWord, DWord, SDWord, Floatx, Float3, Group, Text, ULong, SLong, Float6  # noqa: E501

        :return: The data_type of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this Calibration.

        The data type  None, Byte, SByte, Word, SWord, DWord, SDWord, Floatx, Float3, Group, Text, ULong, SLong, Float6  # noqa: E501

        :param data_type: The data_type of this Calibration.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Byte", "SByte", "Word", "SWord", "DWord", "SDWord", "Floatx", "Float3", "Group", "Text", "ULong", "SLong", "Float6"]  # noqa: E501
        if (self._configuration.client_side_validation and
                data_type not in allowed_values):
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    @property
    def nx(self):
        """Gets the nx of this Calibration.  # noqa: E501

        The X dimension of the data array  # noqa: E501

        :return: The nx of this Calibration.  # noqa: E501
        :rtype: int
        """
        return self._nx

    @nx.setter
    def nx(self, nx):
        """Sets the nx of this Calibration.

        The X dimension of the data array  # noqa: E501

        :param nx: The nx of this Calibration.  # noqa: E501
        :type: int
        """

        self._nx = nx

    @property
    def ny(self):
        """Gets the ny of this Calibration.  # noqa: E501

        The Y dimension of the data array  # noqa: E501

        :return: The ny of this Calibration.  # noqa: E501
        :rtype: int
        """
        return self._ny

    @ny.setter
    def ny(self, ny):
        """Sets the ny of this Calibration.

        The Y dimension of the data array  # noqa: E501

        :param ny: The ny of this Calibration.  # noqa: E501
        :type: int
        """

        self._ny = ny

    @property
    def nz(self):
        """Gets the nz of this Calibration.  # noqa: E501

        The Z dimension of the data array  # noqa: E501

        :return: The nz of this Calibration.  # noqa: E501
        :rtype: int
        """
        return self._nz

    @nz.setter
    def nz(self, nz):
        """Sets the nz of this Calibration.

        The Z dimension of the data array  # noqa: E501

        :param nz: The nz of this Calibration.  # noqa: E501
        :type: int
        """

        self._nz = nz

    @property
    def axe_x(self):
        """Gets the axe_x of this Calibration.  # noqa: E501

        The reference name of the X axis (if the parameter needs axis)  # noqa: E501

        :return: The axe_x of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._axe_x

    @axe_x.setter
    def axe_x(self, axe_x):
        """Sets the axe_x of this Calibration.

        The reference name of the X axis (if the parameter needs axis)  # noqa: E501

        :param axe_x: The axe_x of this Calibration.  # noqa: E501
        :type: str
        """

        self._axe_x = axe_x

    @property
    def axe_y(self):
        """Gets the axe_y of this Calibration.  # noqa: E501

        The reference name of the Y axis (if the parameter needs axis)  # noqa: E501

        :return: The axe_y of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._axe_y

    @axe_y.setter
    def axe_y(self, axe_y):
        """Sets the axe_y of this Calibration.

        The reference name of the Y axis (if the parameter needs axis)  # noqa: E501

        :param axe_y: The axe_y of this Calibration.  # noqa: E501
        :type: str
        """

        self._axe_y = axe_y

    @property
    def axe_z(self):
        """Gets the axe_z of this Calibration.  # noqa: E501

        The reference name of the Z axis (if the parameter needs axis)  # noqa: E501

        :return: The axe_z of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._axe_z

    @axe_z.setter
    def axe_z(self, axe_z):
        """Sets the axe_z of this Calibration.

        The reference name of the Z axis (if the parameter needs axis)  # noqa: E501

        :param axe_z: The axe_z of this Calibration.  # noqa: E501
        :type: str
        """

        self._axe_z = axe_z

    @property
    def calibration_type(self):
        """Gets the calibration_type of this Calibration.  # noqa: E501

        The parameter definition type (Single, 1D, 2D, 3D)  # noqa: E501

        :return: The calibration_type of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._calibration_type

    @calibration_type.setter
    def calibration_type(self, calibration_type):
        """Sets the calibration_type of this Calibration.

        The parameter definition type (Single, 1D, 2D, 3D)  # noqa: E501

        :param calibration_type: The calibration_type of this Calibration.  # noqa: E501
        :type: str
        """
        allowed_values = ["Single", "OneDimension", "TwoDimension", "ThreeDimension"]  # noqa: E501
        if (self._configuration.client_side_validation and
                calibration_type not in allowed_values):
            raise ValueError(
                "Invalid value for `calibration_type` ({0}), must be one of {1}"  # noqa: E501
                .format(calibration_type, allowed_values)
            )

        self._calibration_type = calibration_type

    @property
    def groupe_path(self):
        """Gets the groupe_path of this Calibration.  # noqa: E501

        The group name to which the parameter belongs to.  # noqa: E501

        :return: The groupe_path of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._groupe_path

    @groupe_path.setter
    def groupe_path(self, groupe_path):
        """Sets the groupe_path of this Calibration.

        The group name to which the parameter belongs to.  # noqa: E501

        :param groupe_path: The groupe_path of this Calibration.  # noqa: E501
        :type: str
        """

        self._groupe_path = groupe_path

    @property
    def unit(self):
        """Gets the unit of this Calibration.  # noqa: E501

        The parameter unit  # noqa: E501

        :return: The unit of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this Calibration.

        The parameter unit  # noqa: E501

        :param unit: The unit of this Calibration.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def data_axe_x(self):
        """Gets the data_axe_x of this Calibration.  # noqa: E501

        The X axis data embedded in the parameter  # noqa: E501

        :return: The data_axe_x of this Calibration.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_x

    @data_axe_x.setter
    def data_axe_x(self, data_axe_x):
        """Sets the data_axe_x of this Calibration.

        The X axis data embedded in the parameter  # noqa: E501

        :param data_axe_x: The data_axe_x of this Calibration.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_x = data_axe_x

    @property
    def data_axe_y(self):
        """Gets the data_axe_y of this Calibration.  # noqa: E501

        The Y axis data embedded in the parameter  # noqa: E501

        :return: The data_axe_y of this Calibration.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_y

    @data_axe_y.setter
    def data_axe_y(self, data_axe_y):
        """Sets the data_axe_y of this Calibration.

        The Y axis data embedded in the parameter  # noqa: E501

        :param data_axe_y: The data_axe_y of this Calibration.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_y = data_axe_y

    @property
    def data_axe_z(self):
        """Gets the data_axe_z of this Calibration.  # noqa: E501

        The Z axis data embedded in the parameter  # noqa: E501

        :return: The data_axe_z of this Calibration.  # noqa: E501
        :rtype: list[float]
        """
        return self._data_axe_z

    @data_axe_z.setter
    def data_axe_z(self, data_axe_z):
        """Sets the data_axe_z of this Calibration.

        The Z axis data embedded in the parameter  # noqa: E501

        :param data_axe_z: The data_axe_z of this Calibration.  # noqa: E501
        :type: list[float]
        """

        self._data_axe_z = data_axe_z

    @property
    def is_axe(self):
        """Gets the is_axe of this Calibration.  # noqa: E501

        True if the parameter is an axis  # noqa: E501

        :return: The is_axe of this Calibration.  # noqa: E501
        :rtype: bool
        """
        return self._is_axe

    @is_axe.setter
    def is_axe(self, is_axe):
        """Sets the is_axe of this Calibration.

        True if the parameter is an axis  # noqa: E501

        :param is_axe: The is_axe of this Calibration.  # noqa: E501
        :type: bool
        """

        self._is_axe = is_axe

    @property
    def group_full_path(self):
        """Gets the group_full_path of this Calibration.  # noqa: E501

        The group full path in which the parameter is located  # noqa: E501

        :return: The group_full_path of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._group_full_path

    @group_full_path.setter
    def group_full_path(self, group_full_path):
        """Sets the group_full_path of this Calibration.

        The group full path in which the parameter is located  # noqa: E501

        :param group_full_path: The group_full_path of this Calibration.  # noqa: E501
        :type: str
        """

        self._group_full_path = group_full_path

    @property
    def string_format(self):
        """Gets the string_format of this Calibration.  # noqa: E501

        The parameter string format  # noqa: E501

        :return: The string_format of this Calibration.  # noqa: E501
        :rtype: str
        """
        return self._string_format

    @string_format.setter
    def string_format(self, string_format):
        """Sets the string_format of this Calibration.

        The parameter string format  # noqa: E501

        :param string_format: The string_format of this Calibration.  # noqa: E501
        :type: str
        """

        self._string_format = string_format

    @property
    def upper_limit(self):
        """Gets the upper_limit of this Calibration.  # noqa: E501

        The upper value authorized  # noqa: E501

        :return: The upper_limit of this Calibration.  # noqa: E501
        :rtype: float
        """
        return self._upper_limit

    @upper_limit.setter
    def upper_limit(self, upper_limit):
        """Sets the upper_limit of this Calibration.

        The upper value authorized  # noqa: E501

        :param upper_limit: The upper_limit of this Calibration.  # noqa: E501
        :type: float
        """

        self._upper_limit = upper_limit

    @property
    def lower_limit(self):
        """Gets the lower_limit of this Calibration.  # noqa: E501

        The lower value authorized  # noqa: E501

        :return: The lower_limit of this Calibration.  # noqa: E501
        :rtype: float
        """
        return self._lower_limit

    @lower_limit.setter
    def lower_limit(self, lower_limit):
        """Sets the lower_limit of this Calibration.

        The lower value authorized  # noqa: E501

        :param lower_limit: The lower_limit of this Calibration.  # noqa: E501
        :type: float
        """

        self._lower_limit = lower_limit

    @property
    def read_only(self):
        """Gets the read_only of this Calibration.  # noqa: E501

        True if the parameter is read only  # noqa: E501

        :return: The read_only of this Calibration.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this Calibration.

        True if the parameter is read only  # noqa: E501

        :param read_only: The read_only of this Calibration.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Calibration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Calibration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Calibration):
            return True

        return self.to_dict() != other.to_dict()
